@@ -1,6 +1,6 @@
 #!/usr/local/bin/python2.7
 # ******************************************************************************
-#  $Id: gcps2wld.py 54587021942e38164ce1cd8009e74933fd328f38 2018-04-18 03:01:56 +1000 Ben Elliston $
+#  $Id: gcps2wld.py 8e263710cb425c4a8b76b1f363b98be41ea0a983 2018-04-30 19:40:20 +1000 Ben Elliston $
 #
 #  Name:     gcps2wld
 #  Project:  GDAL Python Interface
@@ -47,7 +47,7 @@ if dataset is None:
 
 gcps = dataset.GetGCPs()
 
-if gcps is None or len(gcps) == 0:
+if gcps is None or not gcps:
     print('No GCPs found on file ' + filename)
     sys.exit(1)
 
