@@ -1,6 +1,6 @@
 #!/usr/local/bin/python2.7
 # *****************************************************************************
-# $Id: gdalinfo.py 8e263710cb425c4a8b76b1f363b98be41ea0a983 2018-04-30 19:40:20 +1000 Ben Elliston $
+# $Id: gdalinfo.py 49be0a98b98b3de8a98426428229d786771d2ebc 2019-03-20 23:38:46 +0100 Even Rouault $
 #
 # Project:  GDAL Utilities
 # Purpose:  Python port of Commandline application to list info about a file.
@@ -503,9 +503,15 @@ def main(argv=None):
                 print("    %3d: %s" % (i, category))
                 i = i + 1
 
-        if hBand.GetScale() != 1.0 or hBand.GetOffset() != 0.0:
+        scale = hBand.GetScale()
+        if not scale:
+            scale = 1.0
+        offset = hBand.GetOffset()
+        if not offset:
+            offset = 0.0
+        if scale != 1.0 or offset != 0.0:
             print("  Offset: %.15g,   Scale:%.15g" %
-                  (hBand.GetOffset(), hBand.GetScale()))
+                  (offset, scale))
 
         if bShowMetadata:
             papszMetadata = hBand.GetMetadata_List()
